(get-started-index)=

# Getting Started

This section introduces you to working with `vak`.

## Installation

The first thing you'll want to do is install `vak` on your system.
You can read how in {ref}`installation`.

## Automated Annotation

Once you get `vak` installed, you'll want to get acquainted with
the workflow you'll use with the library.
To do so, run through {ref}`this hands-on tutorial <autoannotate>`
where you'll automate annotation of birdsong syllables
using a neural network,
[TweetyNet](https://github.com/yardencsGitHub/tweetynet).

```{toctree}
:hidden: true
:maxdepth: 1

installation
autoannotate
```
